import React, { Component } from "react";

export class KindSelect extends Component {
  render() {
    return (
        <select className="kind-select">
          <option>all events</option>
        </select>
    )
  }
}
